package Sys::Info::Driver::Windows::Device;
use strict;
use vars qw( $VERSION );

$VERSION = '0.70';

1;

__END__

=head1 NAME

Sys::Info::Driver::Windows::Device - Base class for Windows device drivers

=head1 SYNOPSIS

    use base qw( Sys::Info::Driver::Windows::Device );

=head1 DESCRIPTION

Base class for Windows device drivers.

=head1 METHODS

None.

=head1 AUTHOR

Burak Grsoy, E<lt>burakE<64>cpan.orgE<gt>

=head1 COPYRIGHT

Copyright 2006-2009 Burak Grsoy. All rights reserved.

=head1 LICENSE

This library is free software; you can redistribute it and/or modify 
it under the same terms as Perl itself, either Perl version 5.10.0 or, 
at your option, any later version of Perl 5 you may have available.

=cut
